@@ -202,9 +202,13 @@ def assert_raises_and_contains(expected_exception_class, strings, callable_obj,
     """
     try:
         callable_obj(*args, **kwargs)
-    except expected_exception_class, e:
+    except expected_exception_class as e:
         message = str(e).lower()
-        if isinstance(strings, basestring):
+        try:
+            is_string = isinstance(strings, basestring)
+        except NameError:
+            is_string = isinstance(strings, str)
+        if is_string:
             strings = [strings]
         for string in strings:
             assert_in(string.lower(), message)
